@@ -33,6 +33,9 @@ import struct
 import os
 import sys
 
+from paramiko.common import MSG_USERAUTH_REQUEST
+from paramiko.ssh_exception import SSHException
+
 GSS_AUTH_AVAILABLE = True
 GSS_EXCEPTIONS = ()
 _API = None
@@ -64,9 +67,6 @@ try:
 except ImportError:
     GSS_AUTH_AVAILABLE = False
 
-from paramiko.common import MSG_USERAUTH_REQUEST
-from paramiko.ssh_exception import SSHException
-
 
 def GSSAuth(auth_method, gss_deleg_creds=True):
     """
@@ -609,7 +609,7 @@ class _SSH_SSPI(_SSH_GSSAuth):
             error, token = self._gss_ctxt.authorize(recv_token)
             token = token[0].Buffer
         except pywintypes.error as e:
-            e.strerror += ", Target: {}".format(e, self._gss_host)
+            e.strerror += ", Target: {}".format(self._gss_host)
             raise
 
         if error == 0:
