@@ -85,7 +85,7 @@ utf8_folder = b'/\xc3\xbcnic\xc3\xb8\x64\x65'
 
 @slow
 class TestSFTP(object):
-    def test_1_file(self, sftp):
+    def test_file(self, sftp):
         """
         verify that we can create a file.
         """
@@ -96,7 +96,7 @@ class TestSFTP(object):
             f.close()
             sftp.remove(sftp.FOLDER + '/test')
 
-    def test_2_close(self, sftp):
+    def test_close(self, sftp):
         """
         Verify that SFTP session close() causes a socket error on next action.
         """
@@ -104,7 +104,7 @@ class TestSFTP(object):
         with pytest.raises(socket.error, match='Socket is closed'):
             sftp.open(sftp.FOLDER + '/test2', 'w')
 
-    def test_2_sftp_can_be_used_as_context_manager(self, sftp):
+    def test_sftp_can_be_used_as_context_manager(self, sftp):
         """
         verify that the sftp session is closed when exiting the context manager
         """
@@ -113,7 +113,7 @@ class TestSFTP(object):
         with pytest.raises(socket.error, match='Socket is closed'):
             sftp.open(sftp.FOLDER + '/test2', 'w')
 
-    def test_3_write(self, sftp):
+    def test_write(self, sftp):
         """
         verify that a file can be created and written, and the size is correct.
         """
@@ -124,7 +124,7 @@ class TestSFTP(object):
         finally:
             sftp.remove(sftp.FOLDER + '/duck.txt')
 
-    def test_3_sftp_file_can_be_used_as_context_manager(self, sftp):
+    def test_sftp_file_can_be_used_as_context_manager(self, sftp):
         """
         verify that an opened file can be used as a context manager
         """
@@ -135,7 +135,7 @@ class TestSFTP(object):
         finally:
             sftp.remove(sftp.FOLDER + '/duck.txt')
 
-    def test_4_append(self, sftp):
+    def test_append(self, sftp):
         """
         verify that a file can be opened for append, and tell() still works.
         """
@@ -153,7 +153,7 @@ class TestSFTP(object):
         finally:
             sftp.remove(sftp.FOLDER + '/append.txt')
 
-    def test_5_rename(self, sftp):
+    def test_rename(self, sftp):
         """
         verify that renaming a file works.
         """
@@ -178,8 +178,7 @@ class TestSFTP(object):
             except:
                 pass
 
-
-    def test_5a_posix_rename(self, sftp):
+    def test_posix_rename(self, sftp):
         """Test posix-rename@openssh.com protocol extension."""
         try:
             # first check that the normal rename works as specified
@@ -208,8 +207,7 @@ class TestSFTP(object):
             except:
                 pass
 
-
-    def test_6_folder(self, sftp):
+    def test_folder(self, sftp):
         """
         create a temporary folder, verify that we can create a file in it, then
         remove the folder and verify that we can't create a file in it anymore.
@@ -222,7 +220,7 @@ class TestSFTP(object):
         with pytest.raises(IOError, match="No such file"):
             sftp.open(sftp.FOLDER + '/subfolder/test')
 
-    def test_7_listdir(self, sftp):
+    def test_listdir(self, sftp):
         """
         verify that a folder can be created, a bunch of files can be placed in
         it, and those files show up in sftp.listdir.
@@ -243,7 +241,7 @@ class TestSFTP(object):
             sftp.remove(sftp.FOLDER + '/fish.txt')
             sftp.remove(sftp.FOLDER + '/tertiary.py')
 
-    def test_7_5_listdir_iter(self, sftp):
+    def test_listdir_iter(self, sftp):
         """
         listdir_iter version of above test
         """
@@ -263,7 +261,7 @@ class TestSFTP(object):
             sftp.remove(sftp.FOLDER + '/fish.txt')
             sftp.remove(sftp.FOLDER + '/tertiary.py')
 
-    def test_8_setstat(self, sftp):
+    def test_setstat(self, sftp):
         """
         verify that the setstat functions (chown, chmod, utime, truncate) work.
         """
@@ -300,7 +298,7 @@ class TestSFTP(object):
         finally:
             sftp.remove(sftp.FOLDER + '/special')
 
-    def test_9_fsetstat(self, sftp):
+    def test_fsetstat(self, sftp):
         """
         verify that the fsetstat functions (chown, chmod, utime, truncate)
         work on open files.
@@ -340,7 +338,7 @@ class TestSFTP(object):
         finally:
             sftp.remove(sftp.FOLDER + '/special')
 
-    def test_A_readline_seek(self, sftp):
+    def test_readline_seek(self, sftp):
         """
         create a text file and write a bunch of text into it.  then count the lines
         in the file, and seek around to retrieve particular lines.  this should
@@ -369,7 +367,7 @@ class TestSFTP(object):
         finally:
             sftp.remove(sftp.FOLDER + '/duck.txt')
 
-    def test_B_write_seek(self, sftp):
+    def test_write_seek(self, sftp):
         """
         create a text file, seek back and change part of it, and verify that the
         changes worked.
@@ -387,14 +385,11 @@ class TestSFTP(object):
         finally:
             sftp.remove(sftp.FOLDER + '/testing.txt')
 
-    def test_C_symlink(self, sftp):
+    @pytest.mark.skipif("not hasattr(os, 'symlink')")  # on windows
+    def test_symlink(self, sftp):
         """
         create a symlink and then check that lstat doesn't follow it.
         """
-        if not hasattr(os, "symlink"):
-            # skip symlink tests on windows
-            return
-
         try:
             with sftp.open(sftp.FOLDER + '/original.txt', 'w') as f:
                 f.write('original\n')
@@ -432,7 +427,7 @@ class TestSFTP(object):
             except:
                 pass
 
-    def test_D_flush_seek(self, sftp):
+    def test_flush_seek(self, sftp):
         """
         verify that buffered writes are automatically flushed on seek.
         """
@@ -452,7 +447,7 @@ class TestSFTP(object):
             except:
                 pass
 
-    def test_E_realpath(self, sftp):
+    def test_realpath(self, sftp):
         """
         test that realpath is returning something non-empty and not an
         error.
@@ -463,7 +458,7 @@ class TestSFTP(object):
         assert len(f) > 0
         assert os.path.join(pwd, sftp.FOLDER) == f
 
-    def test_F_mkdir(self, sftp):
+    def test_mkdir(self, sftp):
         """
         verify that mkdir/rmdir work.
         """
@@ -474,7 +469,7 @@ class TestSFTP(object):
         with pytest.raises(IOError, match="No such file"):
             sftp.rmdir(sftp.FOLDER + '/subfolder')
 
-    def test_G_chdir(self, sftp):
+    def test_chdir(self, sftp):
         """
         verify that chdir/getcwd work.
         """
@@ -510,7 +505,7 @@ class TestSFTP(object):
             except:
                 pass
 
-    def test_H_get_put(self, sftp):
+    def test_get_put(self, sftp):
         """
         verify that get/put work.
         """
@@ -544,7 +539,7 @@ class TestSFTP(object):
         os.unlink(localname)
         sftp.unlink(sftp.FOLDER + '/bunny.txt')
 
-    def test_I_check(self, sftp):
+    def test_check(self, sftp):
         """
         verify that file.check() works against our own server.
         (it's an sftp extension that we support, and may be the only ones who
@@ -564,7 +559,7 @@ class TestSFTP(object):
         finally:
             sftp.unlink(sftp.FOLDER + '/kitty.txt')
 
-    def test_J_x_flag(self, sftp):
+    def test_x_flag(self, sftp):
         """
         verify that the 'x' flag works when opening a file.
         """
@@ -579,7 +574,7 @@ class TestSFTP(object):
         finally:
             sftp.unlink(sftp.FOLDER + '/unusual.txt')
 
-    def test_K_utf8(self, sftp):
+    def test_utf8(self, sftp):
         """
         verify that unicode strings are encoded into utf8 correctly.
         """
@@ -593,7 +588,7 @@ class TestSFTP(object):
             self.fail('exception ' + str(e))
         sftp.unlink(b(sftp.FOLDER) + utf8_folder)
 
-    def test_L_utf8_chdir(self, sftp):
+    def test_utf8_chdir(self, sftp):
         sftp.mkdir(sftp.FOLDER + '/' + unicode_folder)
         try:
             sftp.chdir(sftp.FOLDER + '/' + unicode_folder)
@@ -604,7 +599,7 @@ class TestSFTP(object):
             sftp.chdir()
             sftp.rmdir(sftp.FOLDER + '/' + unicode_folder)
 
-    def test_M_bad_readv(self, sftp):
+    def test_bad_readv(self, sftp):
         """
         verify that readv at the end of the file doesn't essplode.
         """
@@ -620,7 +615,7 @@ class TestSFTP(object):
         finally:
             sftp.unlink(sftp.FOLDER + '/zero')
 
-    def test_N_put_without_confirm(self, sftp):
+    def test_put_without_confirm(self, sftp):
         """
         verify that get/put work without confirmation.
         """
@@ -646,7 +641,7 @@ class TestSFTP(object):
         os.unlink(localname)
         sftp.unlink(sftp.FOLDER + '/bunny.txt')
 
-    def test_O_getcwd(self, sftp):
+    def test_getcwd(self, sftp):
         """
         verify that chdir/getcwd work.
         """
@@ -665,7 +660,7 @@ class TestSFTP(object):
             except:
                 pass
 
-    def XXX_test_M_seek_append(self, sftp):
+    def test_seek_append(self, sftp):
         """
         verify that seek does't affect writes during append.
 
@@ -703,7 +698,7 @@ class TestSFTP(object):
     # appear but they're clearly emitted from subthreads that have no error
     # handling. No point running it until that is fixed somehow.
     @pytest.mark.skip("Doesn't prove anything right now")
-    def test_N_file_with_percent(self, sftp):
+    def test_file_with_percent(self, sftp):
         """
         verify that we can create a file with a '%' in the filename.
         ( it needs to be properly escaped by _log() )
@@ -715,7 +710,7 @@ class TestSFTP(object):
             f.close()
             sftp.remove(sftp.FOLDER + '/test%file')
 
-    def test_O_non_utf8_data(self, sftp):
+    def test_non_utf8_data(self, sftp):
         """Test write() and read() of non utf8 data"""
         try:
             with sftp.open('%s/nonutf8data' % sftp.FOLDER, 'w') as f:
@@ -731,7 +726,6 @@ class TestSFTP(object):
         finally:
             sftp.remove('%s/nonutf8data' % sftp.FOLDER)
 
-
     def test_sftp_attributes_empty_str(self, sftp):
         sftp_attributes = SFTPAttributes()
         assert str(sftp_attributes) == "?---------   1 0        0               0 (unknown date) ?"
@@ -750,7 +744,6 @@ class TestSFTP(object):
         finally:
             sftp.remove('%s/write_buffer' % sftp.FOLDER)
 
-    @needs_builtin('memoryview')
     def test_write_memoryview(self, sftp):
         """Test write() using a memoryview instance."""
         data = 3 * b'A potentially large block of data to chunk up.\n'
